***********************************************************************************
***	DREHER, FUCHS, HODLER, PARKS, RASCHKY & TIERNEY              				***
***	African Leaders and the Geography of China’s Foreign Assistance             ***
***	Journal of Development Economics											***
***	Replication of regression results                           				***
***********************************************************************************

set more off
set matsize 7000



* Create folder "JDE results"
mata: _mkdir("./JDE results") 

cap log close
log using "JDE Results\regressions", replace



* TABLE 2: Baseline
use "SN1 data JDE", clear
estimates drop _all

label var china_aid_flow_totalUSD_0_ln "Total-OLS"
label var china_aid_flow_totalUSD_0 "Total-PPML"
label var china_aid_flow_odaUSD_0_ln "ODA-OLS"
label var china_aid_flow_odaUSD_0 "ODA-PPML"

* Column 1-4: CS
xi: reg china_aid_flow_totalUSD_0_ln birthregion light2000_ln pop2000_ln capital_region mine_all_ln oilgas areakm_ln port_dummy road_density i.cyid if year>=2000 & year<=2011, cluster(id_0)
estimates store china_adm1_cs1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="No"
unique id_1 if e(sample)

	* TABLE 1: Descriptive statistics
	sum china_aid_flow_totalUSD_0 china_aid_flow_odaUSD_0 china_aid_flow_dummy wb_totalamt_loc wb_idacommamt_loc ///
	birthregion pre_birthtwo post_birthtwo spouse_birthregion ///
	light2000 pop2000 capital_region mine_all oilgas areakm port_dummy road_density ///
	exelec legelec eiec liec state2 if e(sample)==1

	* Extract data set with birth projects
	preserve
	keep if e(sample) & birthregion==1
	keep id_0 id_1 year
	gen birthproject=1
	save "birthprojects.dta", replace
	restore
	
poi2hdfe china_aid_flow_totalUSD_0 birthregion light2000_ln pop2000_ln capital_region mine_all_ln oilgas areakm_ln port_dummy road_density if year>=2000 & year<=2011, id1(cyid) id2(year) cluster(id_0)
estimates store Pchina_adm1_cs1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="No"
unique id_1 if e(sample)

xi: reg china_aid_flow_odaUSD_0_ln birthregion light2000_ln pop2000_ln capital_region mine_all_ln oilgas areakm_ln port_dummy road_density i.cyid if year>=2000 & year<=2011, cluster(id_0)
estimates store china_adm1_cs2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="No"
unique id_1 if e(sample)

poi2hdfe china_aid_flow_odaUSD_0 birthregion light2000_ln pop2000_ln capital_region mine_all_ln oilgas areakm_ln port_dummy road_density  if year>=2000 & year<=2011, id1(cyid) id2(year) cluster(id_0)
estimates store Pchina_adm1_cs2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="No"
unique id_1 if e(sample)


* Column 5-8: FE
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fe1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

poi2hdfe china_aid_flow_totalUSD_0 birthregion  if year>=2000 & year<=2011, id1(cyid) id2(id_1)  cluster(id_0)
estimates store Pchina_adm1_fe1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

xi: xtreg china_aid_flow_odaUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fe2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

poi2hdfe china_aid_flow_odaUSD_0 birthregion  if year>=2000 & year<=2011, id1(cyid) id2(id_1)  cluster(id_0)
estimates store Pchina_adm1_fe2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Table 2
estout _all using "JDE Results\Table2.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM1FE r2 N N_g, labels("Country-year FE" "ADM1 FE" "R-squared" "Observations" "Regions") fmt(0 0 2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace

	

* TABLE 3: Pre-birth
use "SN1 data JDE", clear
estimates drop _all

label var china_aid_flow_totalUSD_0_ln "Total-OLS"
label var china_aid_flow_totalUSD_0 "Total-PPML"
label var china_aid_flow_odaUSD_0_ln "ODA-OLS"
label var china_aid_flow_odaUSD_0 "ODA-PPML"

* Column 1-4: FE with prebirth and postbirth
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion pre_birthtwo post_birthtwo i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
test birthregion=pre_birthtwo
estadd scalar birth_prebirth1=r(p), replace
estimates store china_adm1_fepp1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

poi2hdfe china_aid_flow_totalUSD_0 birthregion pre_birthtwo post_birthtwo  if year>=2000 & year<=2011, id1(cyid) id2(id_1)  cluster(id_0)
test birthregion=pre_birthtwo
estadd scalar birth_prebirth1=r(p), replace 
estimates store Pchina_adm1_fepp1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

xi: xtreg china_aid_flow_odaUSD_0_ln birthregion pre_birthtwo post_birthtwo i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
test birthregion=pre_birthtwo
estadd scalar birth_prebirth1=r(p), replace 
estimates store china_adm1_fepp2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

poi2hdfe china_aid_flow_odaUSD_0 birthregion pre_birthtwo post_birthtwo  if year>=2000 & year<=2011, id1(cyid) id2(id_1)  cluster(id_0)
test birthregion=pre_birthtwo
estadd scalar birth_prebirth1=r(p), replace 
estimates store Pchina_adm1_fepp2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)


* Column 5-8: FE with spouses
set more off
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion spouse_birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store spouse_SN1fe1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

poi2hdfe china_aid_flow_totalUSD_0 birthregion spouse_birthregion  if year>=2000 & year<=2011, id1(cyid) id2(id_1)  cluster(id_0)
estimates store Pspouse_SN1fe1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

xi: xtreg china_aid_flow_odaUSD_0_ln birthregion spouse_birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store spouse_SN1fe1oda
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

poi2hdfe china_aid_flow_odaUSD_0 birthregion spouse_birthregion  if year>=2000 & year<=2011, id1(cyid) id2(id_1)  cluster(id_0)
estimates store Pspouse_SN1fe1oda
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Table 3
estout _all using "JDE Results\table3.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM1FE r2 N N_g birth_prebirth1, labels("Country-year FE" "ADM1 FE" "R-squared" "Observations" "Regions" "Birthregion=Prebirth (p-value)") fmt(0 0 2 0 0 3)) drop(_cons _I*) style(tex) numbers("(" ")") replace
	

	
* TABLE 4: Elections
use "SN1 data JDE", clear
estimates drop _all

label var china_aid_flow_totalUSD_0_ln "Total-OLS"
label var china_aid_flow_totalUSD_0 "Total-PPML"
label var china_aid_flow_odaUSD_0_ln "ODA-OLS"
label var china_aid_flow_odaUSD_0 "ODA-PPML"

label var birthregion_exelec "* Executive election next year"
label var birthregion_legelec "* Legislative election next year"
label var birthregion_eiec "* Executive electoral competitiveness"
label var birthregion_liec "* Legislative electoral competitiveness"
label var birthregion_state2 "* Provincial elections"

* Column 1
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion birthregion_exelec i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_elec1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Column 2
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion birthregion_legelec i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_elec2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Column 3
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion birthregion_eiec i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_elec3
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Column 4
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion birthregion_liec i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_elec4
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Column 5
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion birthregion_state2 i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_elec5
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)


* Table 4
estout _all using "JDE Results\table4.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM1FE r2 N N_g, labels("Country-year FE" "ADM1 FE" "R-squared" "Observations" "Regions") fmt(0 0 2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace

	
		
* TABLE 5: ADM2
use "SN2 data JDE", clear
estimates drop _all

label var china_aid_flow_totalUSD_0_ln "Total-OLS"
label var china_aid_flow_totalUSD_0 "Total-PPML"
label var china_aid_flow_odaUSD_0_ln "ODA-OLS"
label var china_aid_flow_odaUSD_0 "ODA-PPML"

* Column 1-4: FE ADM2-birthregions
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm2_fe1
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique objectid if e(sample)
	
poi2hdfe china_aid_flow_totalUSD_0 birthregion  if year>=2000 & year<=2011, id1(objectid) id2(cyid) cluster(id_0)
estimates store Pchina_adm2_fe1
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique objectid if e(sample)

xi: xtreg china_aid_flow_odaUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm2_fe2
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique objectid if e(sample)

poi2hdfe china_aid_flow_odaUSD_0 birthregion  if year>=2000 & year<=2011, id1(objectid) id2(cyid) cluster(id_0)
estimates store Pchina_adm2_fe2
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique objectid if e(sample)


* Column 5-8: FE ADM1&2-birthregions
* For comparison: China SN2: ADM2 regions in ADM1 leader region that are not ADM2 leader region
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion ADM2_birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
test birthregion=ADM2_birthregion
estadd scalar ADM1ADM2_birthregion=r(p), replace
estimates store china_adm2_nest_fe1
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique objectid if e(sample)

poi2hdfe china_aid_flow_totalUSD_0 birthregion ADM2_birthregion  if year>=2000 & year<=2011, id1(objectid) id2(cyid) cluster(id_0)
test birthregion=ADM2_birthregion
estadd scalar ADM1ADM2_birthregion=r(p), replace
estimates store Pchina_adm2_nest_fe1
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique objectid if e(sample)

xi: xtreg china_aid_flow_odaUSD_0_ln birthregion ADM2_birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
test birthregion=ADM2_birthregion
estadd scalar ADM1ADM2_birthregion=r(p), replace
estimates store china_adm2_nest_fe2
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique objectid if e(sample)

poi2hdfe china_aid_flow_odaUSD_0 birthregion ADM2_birthregion  if year>=2000 & year<=2011, id1(objectid) id2(cyid) cluster(id_0)
test birthregion=ADM2_birthregion
estadd scalar ADM1ADM2_birthregion=r(p), replace
estimates store Pchina_adm2_nest_fe2
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique objectid if e(sample)


* Table 5 (tab:china5)
estout _all using "JDE Results\table5.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM2FE r2 N N_g ADM1ADM2_birthregion, labels("Country-year FE" "ADM2 FE" "R-squared" "Observations" "Regions" "Birthregion (same ADM2)=Birthregion (other in ADM1) (p-value)") fmt(0 0 2 0 0 3)) drop(_cons _I*) style(tex) numbers("(" ")") replace



* TABLE 6: World Bank

* Column 1-4: FE ADM1
use "SN1 data JDE", clear
estimates drop _all

label var china_aid_flow_totalUSD_0_ln "Total-OLS"
label var china_aid_flow_totalUSD_0 "Total-PPML"
label var china_aid_flow_odaUSD_0_ln "ODA-OLS"
label var china_aid_flow_odaUSD_0 "ODA-PPML"
label var wb_totalamt_loc_ln "Total-OLS"
label var wb_idacommamt_loc "Total-PPML"
label var wb_totalamt_loc_ln "ODA-OLS"
label var wb_idacommamt_loc "ODA-PPML"

xi: xtreg wb_totalamt_loc_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store wb_adm1_fe1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

poi2hdfe wb_totalamt_loc birthregion  if year>=2000 & year<=2011, id1(id_1) id2(cyid) cluster(id_0)
estimates store Pwb_adm1_fe1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

xi: xtreg wb_idacommamt_loc_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store wb_adm1_fe2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

poi2hdfe wb_idacommamt_loc birthregion  if year>=2000 & year<=2011, id1(id_1) id2(cyid) cluster(id_0)
estimates store Pwb_adm1_fe2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)


* Column 5-8: FE ADM2
use "SN2 data JDE", clear
xi: xtreg wb_totalamt_loc_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store wb_adm2_fe1
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique objectid if e(sample)

poi2hdfe wb_totalamt_loc birthregion  if year>=2000 & year<=2011, id1(objectid) id2(cyid) cluster(id_0)
estimates store Pwb_adm2_fe1
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique objectid if e(sample)

xi: xtreg wb_idacommamt_loc_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store wb_adm2_fe2
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique objectid if e(sample)

poi2hdfe wb_idacommamt_loc birthregion  if year>=2000 & year<=2011, id1(objectid) id2(cyid) cluster(id_0)
estimates store Pwb_adm2_fe2
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique objectid if e(sample)


* Table 6
estout _all using "JDE Results\table6.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM1FE ADM2FE r2 N N_g, labels("Country-year FE" "ADM1 FE" "ADM2 FE" "R-squared" "Observations" "Regions") fmt(0 0 0 2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace

	

* TABLE 7: Elections and the World Bank
use "SN1 data JDE", clear
estimates drop _all

label var wb_totalamt_loc_ln "Total-OLS"
label var wb_idacommamt_loc "Total-PPML"
label var wb_totalamt_loc_ln "ODA-OLS"
label var wb_idacommamt_loc "ODA-PPML"

label var birthregion_exelec "* Executive election next year"
label var birthregion_legelec "* Legislative election next year"
label var birthregion_eiec "* Executive electoral competitiveness"
label var birthregion_liec "* Legislative electoral competitiveness"
label var birthregion_state2 "* Provincial elections"

* Column 1
xi: xtreg wb_totalamt_loc_ln birthregion birthregion_exelec i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store wb_adm1_elec1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Column 2
xi: xtreg wb_totalamt_loc_ln birthregion birthregion_legelec i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store wb_adm1_elec2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Column 3
xi: xtreg wb_totalamt_loc_ln birthregion birthregion_eiec i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store wb_adm1_elec3
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Column 4
xi: xtreg wb_totalamt_loc_ln birthregion birthregion_liec i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store wb_adm1_elec4
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Column 5
xi: xtreg wb_totalamt_loc_ln birthregion birthregion_state2 i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store wb_adm1_elec6
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)


* Table 7
estout _all using "JDE Results\Table7.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM1FE r2 N N_g, labels("Country-year FE" "ADM1 FE" "R-squared" "Observations" "Regions") fmt(0 0 2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace



* APPENDIX C: Partial leverage plots
gen avplotlabel=countrycode+years

* Table 2, column 1
* reg dep_var controls
xi: reg china_aid_flow_totalUSD_0_ln light2000_ln pop2000_ln capital_region mine_all_ln oilgas areakm_ln port_dummy road_density i.cyid if year>=2000 & year<=2011, cluster(id_0)
predict dep_var_res if e(sample), res

* reg expl_var controls
xi: reg birthregion light2000_ln pop2000_ln capital_region mine_all_ln oilgas areakm_ln port_dummy road_density i.cyid if year>=2000 & year<=2011, cluster(id_0)
predict expl_var_res if e(sample), res

graph tw scatter dep_var_res expl_var_res if e(sample), 	///
l2title("e(Chinese aid, log total flows | X)") b2title("e(Birthregion | X)") mlabel(avplotlabel) note("") ytitle("") xtitle("") 	///
xscale(range (-0.9 -0.6 1.5)) xlab(-0.9 -0.6 -0.3 0 0.3 0.6 0.9 1.2 1.5) graphregion(color(white)) bgcolor(white) legend(off) || lfit dep_var_res expl_var_res


* Table 2, column 5
* reg dep_var controls
xi: xtreg china_aid_flow_totalUSD_0_ln i.cyid if year>=2000 & year<=2011, fe cluster(id_0) nonest
predict dep_var_res1 if e(sample), ue

* reg expl_var controls
xi: xtreg birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0) nonest
predict expl_var_res1 if e(sample), ue

graph tw scatter dep_var_res1 expl_var_res1 if e(sample), 	///
l2title("e(Chinese aid, log total flows | X)") b2title("e(Birthregion | X)") mlabel(avplotlabel) note("") ytitle("") xtitle("") 	///
xscale(range (-0.6 1.5)) xlab(-0.6 -0.3 0 0.3 0.6 0.9 1.2 1.5) legend(off) graphregion(color(white)) bgcolor(white) || lfit dep_var_res1 expl_var_res1



* APPENDIX D: Project characteristics
use "china_aid_data_SN.dta", clear
drop if adm0_name =="Somalia"
drop if adm0_name =="Cape Verde"
drop if adm0_name =="Comoros"
drop if adm0_name =="Mauritius"

su project_id /*2,969*/
su project_id if precision_code<5 /*1898 ADM1 projects*/
su project_id if precision_code<4 /*1575 ADM2 projects*/
su project_id if precision_code>4 /*1071 projects without precise location */

su usd_defl if precision_code>4, detail /*1071 projects without precise location*/
/*
mean loan amount all projects: 7.05e+07
median loan amount all projects:  7262775
number of projects with loan amounts: 648
share of projects without loan amounts: 0.400 (=1-(648/1071))
*/

su usd_defl if precision_code<5, detail  /*1898 ADM1 projects*/
/*
mean loan amount all projects: 2.36e+08
median loan amount all projects:  3.58e+07
number of projects with loan amounts: 1397
share of projects without loan amounts: 0.264 (=1-(1397/1898))
*/

tab status if precision_code>4, sort
tab status if precision_code<5, sort
* share of projects in the pipeline much larger for projects without locational details

tab crs_sector_name if precision_code>4, sort
tab crs_sector_name if precision_code<5, sort
* 20% "Unallocated / Unspecified" for projects without locational details

tab flow if precision_code>4, sort
tab flow if precision_code<5, sort
* Loans have more detailed project locations (as these include some of the largest projects, with more information being available (though mean loan size is smaller))
su usd_defl if flow=="Loan (excluding debt rescheduling)", detail 

tab flow_class if precision_code>4, sort
tab flow_class if precision_code<5, sort
* ODA projects have less precise locational information




* APPENDIX E.1: Treatment of missing values
use "SN1 data JDE", clear
estimates drop _all

xi: xtreg china_aid_flow_totalUSD_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fe11
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

use "SN2 data JDE", clear

xi: xtreg china_aid_flow_totalUSD_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fe12
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique id_1 if e(sample)

use "SN1 data JDE", clear

xi: xtreg china_aid_flow_odaUSD_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fe21
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

use "SN2 data JDE", clear

xi: xtreg china_aid_flow_odaUSD_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fe22
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique id_1 if e(sample)


* Appendix E.1
estout _all using "JDE Results\AppendixE1.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM1FE ADM2FE r2 N N_g, labels("Country-year FE" "ADM1 FE" "ADM2 FE" "R-squared" "Observations" "Regions") fmt(0 0 0 2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace

	
	
* APPENDIX E.2: Dummy
use "SN1 data JDE", clear
estimates drop _all

label var china_aid_flow_dummy "Total-OLS"

* Column 1
xi: reg china_aid_flow_dummy birthregion light2000_ln pop2000_ln capital_region mine_all_ln oilgas areakm_ln port_dummy road_density i.cyid if year>=2000 & year<=2011, cluster(id_0)
estimates store china_adm1_cs3
estadd local CountryYearFE="Yes"
estadd local ADM1FE="No"
unique id_1 if e(sample)

* Column 2
xi: xtreg china_aid_flow_dummy birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fe3
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Appendix E.2
estout _all using "JDE Results\AppendixE2.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM1FE r2 N N_g, labels("Country-year FE" "ADM1 FE" "R-squared" "Observations" "Regions") fmt(0 0 2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace

	
	
* APPENDIX E.3: Various clusters
use "SN1 data JDE", clear
estimates drop _all
tab cyid, gen(Dcyid)

xi: xtreg china_aid_flow_totalUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_clust1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
estadd local Cluster1="Country"
unique id_1 if e(sample)

xi: xtreg china_aid_flow_totalUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(leaderid) nonest
estimates store china_clust2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
estadd local Cluster1="Leader"
unique id_1 if e(sample)

xi: xtreg china_aid_flow_totalUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_1)
estimates store china_clust3
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
estadd local Cluster1="ADM1"
unique id_1 if e(sample)

xi: xtivreg2 china_aid_flow_totalUSD_0_ln birthregion Dcyid* if year>=2000 & year<=2011, fe cluster(id_0 year)
estimates store china_clust4
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
estadd local Cluster1="Country"
estadd local Cluster2="Year"
unique id_1 if e(sample)

xi: xtivreg2 china_aid_flow_totalUSD_0_ln birthregion Dcyid* if year>=2000 & year<=2011, fe cluster(id_1 year)
estimates store china_clust5
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
estadd local Cluster1="ADM1"
estadd local Cluster2="Year"
unique id_1 if e(sample)

xi: xtivreg2 china_aid_flow_totalUSD_0_ln birthregion Dcyid* if year>=2000 & year<=2011, fe cluster(id_1 cyid)
estimates store china_clust6
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
estadd local Cluster1="ADM1"
estadd local Cluster2="Country-year"
unique id_1 if e(sample)

drop Dcyid*

* Appendix E.3
estout _all using "JDE Results\AppendixE3.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM1FE Cluster1 Cluster2 r2 N N_g, labels("Country-year FE" "ADM1 FE" "Cluster 1" "Cluster 2" "R-squared" "Observations" "Regions") fmt(0 0 0 0 2 0)) drop(_cons _I* Dcyid*, relax) style(tex) numbers("(" ")") replace


	
* APPENDIX E.4: Project size
use "SN1 data JDE", clear
estimates drop _all
gen china_aid_size=china_aid_flow_totalUSD_0/china_aid_flow_total
gen china_aid_size_ln=log(china_aid_size+1)
xi: xtreg china_aid_size_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
est store china_adm1_size
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

use "SN2 data JDE", clear
gen china_aid_size=china_aid_flow_totalUSD_0/china_aid_flow_total
gen china_aid_size_ln=log(china_aid_size+1)
xi: xtreg china_aid_size_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
est store china_adm2_size
estadd local CountryYearFE="Yes"
estadd local ADM2FE="Yes"
unique objectid if e(sample)

* Appendix E.4
estout _all using "JDE Results\AppendixE4.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM1FE ADM2FE r2 N N_g, labels("Country-year FE" "ADM1 FE" "ADM2 FE" "R-squared" "Observations" "Regions") fmt(0 0 0 2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace

	

* APPENDIX E.5: Heterogenous effects
use "SN1 data JDE", clear
estimates drop _all

* Column 1
label var birthregion_tenure "Interaction"
clonevar interaction=birthregion_tenure
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion interaction i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fehe1
estadd local inter="Tenure"
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)
drop interaction

* Column 2
label var birthregion_polity "Interaction"
clonevar interaction=birthregion_polity
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion interaction i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fehe2
estadd local inter="Polity"
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
drop interaction

* Column 3
label var birthregion_bureaucracy "Interaction"
clonevar interaction=birthregion_bureaucracy
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion interaction i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fehe3
estadd local inter="Bureaucracy"
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)
drop interaction

* Column 4
label var birthregion_corruption "Interaction"
clonevar interaction=birthregion_corruption
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion interaction i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fehe4
estadd local inter="Corruption"
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)
drop interaction

* Column 5
label var birthregion_schooling "Interaction"
clonevar interaction=birthregion_school
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion interaction i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fehe5
estadd local inter="School"
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)
drop interaction

* Column 6
label var birthregion_oilgas "Interaction"
clonevar interaction=birthregion_oilgas
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion interaction i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fehe6
estadd local inter="Oil gas"
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)
drop interaction

* Column 7
label var birthregion_mines "Interaction"
clonevar interaction=birthregion_mines
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion interaction i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fehe7
estadd local inter="Mines"
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)
drop interaction

* Column 8
label var birthregion_agree2un "Interaction"
clonevar interaction=birthregion_agree2un
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion interaction i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fehe8
estadd local inter="UN agreem."
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)
drop interaction

* Column 9
label var birthregion_ipdistance "Interaction"
clonevar interaction=birthregion_ipdistance
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion interaction i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fehe9
estadd local inter="UN dist."
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)
drop interaction

* Column 10
gen light_mean_ln=log(light_mean+0.01)
gen birthregion_light=birthregion*l.light_mean_ln
label var birthregion_light "Interaction"
clonevar interaction=birthregion_light
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion interaction i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fehe10
estadd local inter="Light"
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)
drop interaction

* Appendix E.5
estout _all using "JDE Results\AppendixE5.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM1FE r2 N N_g inter, labels("Country-year FE" "ADM1 FE" "R-squared" "Observations" "Regions" "Interacted with") fmt(0 0 2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace
	
	

* APPENDIX E.6: Sectors
use "SN1 data JDE", clear
estimates drop _all
label var china_aid_flow_socUSD_0_ln "Social"
xi: xtreg china_aid_flow_socUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fe1_soc
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

label var china_aid_flow_ecoUSD_0_ln "Economic"
xi: xtreg china_aid_flow_ecoUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fe1_eco
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

label var china_aid_flow_proUSD_0_ln "Production"
xi: xtreg china_aid_flow_proUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fe1_pro
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Appendix E.6
estout _all using "JDE Results\AppendixE6.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM1FE r2 N N_g, labels("Country-year FE" "ADM1 FE" "R-squared" "Observations" "Regions") fmt(0 0 2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace

	

* APPENDIX E.7: Variants of prebirth
use "SN1 data JDE", clear

label var pre_birth "Prebirth"
label var post_birth "Postbirth (1st year)"
label var post_birth2 "Postbirth (2nd year)"

estimates drop _all
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion pre_birth post_birth i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fepptwo1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

xi: xtreg china_aid_flow_odaUSD_0_ln birthregion pre_birth post_birth i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fepptwo2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

xi: xtreg china_aid_flow_totalUSD_0_ln birthregion pre_birth post_birth post_birth2 i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fepptwo4
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

xi: xtreg china_aid_flow_odaUSD_0_ln birthregion pre_birth post_birth post_birth2 i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fepptwo5
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Appendix E.7
estout _all using "JDE Results\AppendixE7.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM1FE r2 N N_g, labels("Country-year FE" "ADM1 FE" "R-squared" "Observations" "Regions") fmt(0 0 2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace
	
	

* APPENDIX E.8: Exclusion of various project types
use "SN1 data JDE", clear
estimates drop _all

* Project amounts without projects>median of projects without precise locations: 7262775 
xi: xtreg china_aid_flow_smallUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011 & china_aid_flow_totalUSD_0<=7262774, fe cluster(id_0)
estimates store china_adm1_c2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)


* Exclude projects with status==Pipeline: Implementation/Completion
xi: xtreg china_aid_flow_comUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_c3
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)


* Exclude projects with flow=="Loan (excluding debt rescheduling)"
xi: xtreg china_aid_flow_nol2USD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_c5
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Appendix E.8
estout _all using "JDE Results\AppendixE8.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM1FE r2 N N_g, labels("Country-year FE" "ADM1 FE" "R-squared" "Observations" "Regions") fmt(0 0 2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace

		
	
* APPENDIX E.9: Remove one country each
use "SN1 data JDE", clear
estimates drop _all
encode country, gen(cid)

xi: xtreg china_aid_flow_totalUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_R0
estadd local cid="Baseline"

forvalues i=1/47 { 
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011 & cid!=`i', fe cluster(id_0)
estimates store china_adm2_R`i'
estadd local cid="`i'"
}

* Appendix E.9
estout _all using "JDE Results\AppendixE9.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(r2 N N_g cid, labels("R-squared" "Observations" "Regions" "Country ID removed") fmt(2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace



* APPENDIX E.10 Remove one year each
use "SN1 data JDE", clear
estimates drop _all

xi: xtreg china_aid_flow_totalUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe nonest cluster(id_0)
estimates store china_adm1_RY
estadd local cid="Baseline"

forvalues i=2000/2011 { 
xi: xtreg china_aid_flow_totalUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011 & year!=`i', fe nonest cluster(id_0)
estimates store china_adm2_RY`i'
estadd local cid="`i'"
tab year if e(sample)
}

* Appendix E.10
estout _all using "JDE Results\AppendixE10.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(r2 N N_g cid, labels("R-squared" "Observations" "Regions" "Year removed") fmt(2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace


	
* APPENDIX E.11: Baseline with logged aid p.c.
use "SN1 data JDE", clear
estimates drop _all

gen china_aid_pc_totalUSD_0=china_aid_flow_totalUSD_0/pop2000
gen china_aid_pc_totalUSD_0a=(china_aid_flow_totalUSD_0+1)/pop2000
gen china_aid_pc_totalUSD_0_ln=log(china_aid_pc_totalUSD_0a)
drop china_aid_pc_totalUSD_0a
gen china_aid_pc_odaUSD_0=china_aid_flow_odaUSD_0/pop2000
gen china_aid_pc_odaUSD_0a=(china_aid_flow_odaUSD_0+1)/pop2000
gen china_aid_pc_odaUSD_0_ln=log(china_aid_pc_odaUSD_0a)
drop china_aid_pc_odaUSD_0a

label var china_aid_pc_totalUSD_0_ln "Total-OLS-log aid pc"
label var china_aid_pc_totalUSD_0 "Total-OLS-aid pc"
label var china_aid_pc_odaUSD_0_ln "ODA-OLS-log aid pc"
label var china_aid_pc_odaUSD_0 "ODA-OLS-aid pc"

* Column 1-4: CS
xi: reg china_aid_pc_totalUSD_0_ln birthregion light2000_ln capital_region mine_all_ln oilgas areakm_ln port_dummy road_density i.cyid if year>=2000 & year<=2011, cluster(id_0)
estimates store china_adm1_cs1l
estadd local CountryYearFE="Yes"
estadd local ADM1FE="No"
unique id_1 if e(sample)

poi2hdfe china_aid_pc_totalUSD_0 birthregion light2000_ln capital_region mine_all_ln oilgas areakm_ln port_dummy road_density if year>=2000 & year<=2011, id1(cyid) id2(year) cluster(id_0)
estimates store Pchina_adm1_cs1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="No"
unique id_1 if e(sample)

xi: reg china_aid_pc_odaUSD_0_ln birthregion light2000_ln capital_region mine_all_ln oilgas areakm_ln port_dummy road_density i.cyid if year>=2000 & year<=2011, cluster(id_0)
estimates store china_adm1_cs2l
estadd local CountryYearFE="Yes"
estadd local ADM1FE="No"
unique id_1 if e(sample)

poi2hdfe china_aid_pc_odaUSD_0 birthregion light2000_ln capital_region mine_all_ln oilgas areakm_ln port_dummy road_density  if year>=2000 & year<=2011, id1(cyid) id2(year) cluster(id_0)
estimates store Pchina_adm1_cs2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="No"
unique id_1 if e(sample)
	
* Column 5-8: FE
xi: xtreg china_aid_pc_totalUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fe1l
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

poi2hdfe china_aid_pc_totalUSD_0 birthregion  if year>=2000 & year<=2011, id1(cyid) id2(id_1)  cluster(id_0)
estimates store Pchina_adm1_fe1
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

xi: xtreg china_aid_pc_odaUSD_0_ln birthregion i.cyid if year>=2000 & year<=2011, fe cluster(id_0)
estimates store china_adm1_fe2l
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

poi2hdfe china_aid_pc_odaUSD_0 birthregion  if year>=2000 & year<=2011, id1(cyid) id2(id_1)  cluster(id_0)
estimates store Pchina_adm1_fe2
estadd local CountryYearFE="Yes"
estadd local ADM1FE="Yes"
unique id_1 if e(sample)

* Appendix E.11
estout _all using "JDE Results\AppendixE11.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE ADM1FE r2 N N_g, labels("Country-year FE" "ADM1 FE" "R-squared" "Observations" "Regions") fmt(0 0 2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace

		

* APPENDIX F.1: GREG
use "GREG data JDE", clear
estimates drop _all

label var china_aid_flow_totalUSD_0_ln "Total-OLS"
label var china_aid_flow_odaUSD_0_ln "ODA-OLS"

* Column 1-2: CS
xi: reg china_aid_flow_totalUSD_0_ln ethnicity light2000_ln pop2000_ln capital_region mine_all_ln oilgas areakm_ln port_dummy road_density i.cyid if year>=2000 & year<=2011, cluster(ccode)
estimates store china_adm1_cs1g
estadd local CountryYearFE="Yes"
estadd local GREGFE="No"
unique featureid if e(sample)

xi: reg china_aid_flow_odaUSD_0_ln ethnicity light2000_ln pop2000_ln capital_region mine_all_ln oilgas areakm_ln port_dummy road_density i.cyid if year>=2000 & year<=2011, cluster(ccode)
estimates store china_adm1_cs2g
estadd local CountryYearFE="Yes"
estadd local GREGFE="No"
unique featureid if e(sample)


* Column 3-4: FE
xi: xtreg china_aid_flow_totalUSD_0_ln ethnicity i.cyid if year>=2000 & year<=2011, fe cluster(ccode)
estimates store china_adm1_fe1g
estadd local CountryYearFE="Yes"
estadd local GREGFE="Yes"
unique featureid if e(sample)

xi: xtreg china_aid_flow_odaUSD_0_ln ethnicity i.cyid if year>=2000 & year<=2011, fe cluster(ccode)
estimates store china_adm1_fe2g
estadd local CountryYearFE="Yes"
estadd local GREGFE="Yes"
unique featureid if e(sample)


* Table 6 (tab:china6)
estout _all using "JDE Results\appendixF1.txt", cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	mlabel(, depvars) collabels(none) label prehead(\begin{tabular}{l*{@M}{c}} "\hline") posthead("\hline") postfoot("\hline" "\end{tabular}") ///
	noabbrev stats(CountryYearFE GREGFE r2 N N_g, labels("Country-year FE" "GREG FE" "R-squared" "Observations" "Regions") fmt(0 0 2 0)) drop(_cons _I*) style(tex) numbers("(" ")") replace

log close
